(function ($, Drupal) {
  'use strict';

  /**
   * Watches for mouse movement towards the top of the screen which probably
   * indicates a desire to close the tab. When triggered, launches a colorbox
   * modal containing the Exit Modal block.
   */
  Drupal.behaviors.exitModal = {
    attach: function (context, settings) {

      if (!$.isFunction($.colorbox) || typeof settings.colorbox === 'undefined') {
        return;
      }

      function exitModalWatch() {
        var popupId = '#block-exit-modal-exit-modal';
        var colorboxId = '#colorbox';
        // Stop if no popup element.
        if ($('#block-exit-modal-exit-modal').length === 0) {
          return;
        }

        // Override a couple of settings.
        settings.colorbox.inline = true;
        settings.colorbox.href = popupId;

        // Make it happen.
        function popup() {
          $.colorbox(settings.colorbox);
          $(colorboxId).addClass('exit-modal-shown');
        }

        // On page exit - only begin after a couple of seconds to avoid
        // accidental triggering.
        setTimeout(function () {
          $(document).bind('mousemove', function (e) {
            if (e.pageY - $(window).scrollTop() <= 15) {
              popup();
            }
          });
        }, 2000);

        // Stop it from happening more than once.
        $(document).bind('cbox_closed', function () {
          $(document).unbind('mousemove');
          $(colorboxId).removeClass('exit-modal-shown');
        });
      }

      $(window).load(function () {
        exitModalWatch();
      });

    }
  };

})(jQuery, Drupal);
